package com.parse.web.service.impl;

import java.util.List;

import javax.ws.rs.core.MediaType;

import org.codehaus.jackson.map.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.parse.web.beans.Article;
import com.parse.web.beans.Pagination;
import com.parse.web.beans.RestResponse;
import com.parse.web.service.ArticleService;
import com.parse.web.util.OperationUtil;
import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.ClientResponse;
import com.sun.jersey.api.client.WebResource;

@Service(value="articleService")
public class ArticleServiceImpl extends BaseService implements ArticleService {

	/**
	 * 
	 */
	private static final long serialVersionUID = -7757320787525862607L;

	@Autowired
	private Client client;
	@Autowired
	private ObjectMapper objectMapper;
	
	@SuppressWarnings("unchecked")
	@Override
	public RestResponse<Article> getAllArticles(Pagination pagination) throws Exception {
		WebResource webResource = client.resource("https://api.parse.com/1/classes/Article")
		            .queryParam("include", "categories")             
		            .queryParam("limit", getPaginationLimit(pagination))
		            .queryParam("skip", getPaginationStart(pagination))
		            .queryParam("order", "-createdAt")
		            .queryParam("count","1");
		ClientResponse clientResponse = webResource.type(MediaType.APPLICATION_FORM_URLENCODED)
				.header("X-Parse-Application-ID", getApplicationId())
				.header("X-Parse-REST-API-Key", getApiKey())
				.accept(MediaType.APPLICATION_JSON).get(ClientResponse.class);
		String response = clientResponse.getEntity(String.class);
		return objectMapper.readValue(response, RestResponse.class);
	}
	
	@SuppressWarnings("unchecked")
	@Override
	public RestResponse<Article> getArticlesByIds(Pagination pagination,List<String> articles) throws Exception {
		if(articles==null || articles.isEmpty()){
			return null;
		}
		WebResource webResource = client.resource("https://api.parse.com/1/classes/Article")
		            .queryParam("include", "categories")             
		            .queryParam("limit", getPaginationLimit(pagination))
		            .queryParam("skip", getPaginationStart(pagination))
		            .queryParam("order", "-createdAt")
		            .queryParam("where", "{\"objectId\":"+OperationUtil.inClauseJson(articles)+"}");

		ClientResponse clientResponse = webResource.type(MediaType.APPLICATION_FORM_URLENCODED)
				.header("X-Parse-Application-ID", getApplicationId())
				.header("X-Parse-REST-API-Key", getApiKey())
				.accept(MediaType.APPLICATION_JSON).get(ClientResponse.class);
		String response = clientResponse.getEntity(String.class);
		return objectMapper.readValue(response,RestResponse.class);
	}

}
