package com.parse.web.service.impl;

import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.core.MediaType;

import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.type.TypeFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.parse.web.beans.Article;
import com.parse.web.beans.Category;
import com.parse.web.beans.Pagination;
import com.parse.web.beans.RestResponse;
import com.parse.web.service.ArticleService;
import com.parse.web.service.CategoryService;
import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.ClientResponse;
import com.sun.jersey.api.client.WebResource;

@Service(value="categoryService")
public class CategoryServiceImpl extends BaseService implements CategoryService{

	/**
	 * 
	 */
	private static final long serialVersionUID = -2874443557990733594L;
	@Autowired
	private Client client;
	@Autowired
	private ObjectMapper objectMapper;
	@Autowired
	private ArticleService articleService;
	
	@Override
	public void save() throws Exception {
		
	}

	@Override
	public RestResponse<Article> fetchCategoryById(String categoryId) throws Exception {
		WebResource webResource = client.resource("https://api.parse.com/1/classes/Category/")
		                          .path(categoryId)
        						  .queryParam("include", "articles");
		ClientResponse clientResponse = webResource.type(MediaType.APPLICATION_FORM_URLENCODED)
			.header("X-Parse-Application-ID", getApplicationId())
			.header("X-Parse-REST-API-Key", getApiKey())
			.accept(MediaType.APPLICATION_JSON).get(ClientResponse.class);
		String response = clientResponse.getEntity(String.class);
		
		Category category = objectMapper.readValue(response, Category.class);
		List<String> articleIds = new ArrayList<String>();
		if(category.getArticles()!=null &&  !category.getArticles().isEmpty()){
			for (Article article : category.getArticles()){
				articleIds.add(article.getObjectId());
			}
			return articleService.getArticlesByIds(new Pagination(), articleIds);
		}
		return null;

	}

	@Override
	public List<Category> fetchAllCategories(Pagination pagination) throws Exception {
		WebResource webResource = client.resource("https://api.parse.com/1/classes/Category/")
									.queryParam("include", "categories")             
						            .queryParam("limit", getPaginationLimit(pagination))
						            .queryParam("skip", getPaginationStart(pagination))
						            .queryParam("order", "-createdAt");
		ClientResponse clientResponse = webResource.type(MediaType.APPLICATION_FORM_URLENCODED)
				.header("X-Parse-Application-ID", getApplicationId())
				.header("X-Parse-REST-API-Key", getApiKey())
				.accept(MediaType.APPLICATION_JSON).get(ClientResponse.class);
		String response = clientResponse.getEntity(String.class);
		System.out.println(response);
		return objectMapper.readValue(makeJsonCompatible(response), TypeFactory.collectionType(ArrayList.class,Category.class));

	}

}
